Struct iproute2::LinkSetRequest [−][src]
pub struct LinkSetRequest { /* fields omitted */ }Methods
impl LinkSetRequest[src]
impl LinkSetRequestpub fn execute(
self
) -> impl Future<Item = (), Error = NetlinkIpError>[src]
pub fn execute(
self
) -> impl Future<Item = (), Error = NetlinkIpError>Execute the request
pub fn message_mut(&mut self) -> &mut LinkMessage[src]
pub fn message_mut(&mut self) -> &mut LinkMessageReturn a mutable reference to the request
pub fn up(self) -> Self[src]
pub fn up(self) -> SelfSet the link with the given index up (equivalent to ip link set dev DEV up)
pub fn down(self) -> Self[src]
pub fn down(self) -> SelfSet the link with the given index down (equivalent to ip link set dev DEV down)
pub fn name(self, name: String) -> Self[src]
pub fn name(self, name: String) -> SelfSet the name of the link with the given index (equivalent to ip link set DEV name NAME)
pub fn mtu(self, mtu: u32) -> Self[src]
pub fn mtu(self, mtu: u32) -> SelfSet the mtu of the link with the given index (equivalent to ip link set DEV mtu MTU)
pub fn address(self, address: MacAddress) -> Self[src]
pub fn address(self, address: MacAddress) -> SelfSet the hardware address of the link with the given index (equivalent to ip link set DEV address ADDRESS)